==> blesta-5.10.2.zip: blesta/plugins/download_manager/language/pl_pl/download_manager_files.php <==
<?php
/**
 * Download Manager Files
 *
 * @package blesta
 * @subpackage blesta.language.pl_pl
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DownloadManagerFiles.!error.file_id.exists'] = 'Aktualizowany plik nie istnieje.';
$lang['DownloadManagerFiles.!error.file_packages.format'] = 'Co najmniej jeden wybrany pakiet nie może zostać dodany, ponieważ nie istnieje.';
$lang['DownloadManagerFiles.!error.permit_packages.format'] = 'Opcja dostępności pakietu ma nieprawidłowy format.';
$lang['DownloadManagerFiles.!error.file_groups.format'] = 'Co najmniej jedna wybrana grupa klientów nie może zostać dodana, ponieważ nie istnieje.';
$lang['DownloadManagerFiles.!error.permit_client_groups.format'] = 'Opcja dostępności grupy klientów ma nieprawidłowy format.';
$lang['DownloadManagerFiles.!error.public.assignment'] = 'Plik musi być dostępny publicznie, dla grup klientów lub pakietów.';
$lang['DownloadManagerFiles.!error.public.format'] = 'Opcja dostępności publicznej ma nieprawidłowy format.';
$lang['DownloadManagerFiles.!error.file_name.format'] = 'Prześlij plik lub wprowadź prawidłową ścieżkę do pliku.';
$lang['DownloadManagerFiles.!error.name.empty'] = 'Wprowadź nazwę dla tego pliku.';
$lang['DownloadManagerFiles.!error.company_id.exists'] = 'Nieprawidłowy identyfikator firmy.';
$lang['DownloadManagerFiles.!error.category_id.exists'] = 'Wybierz odpowiednią kategorię.';

==> blesta-5.11.4.zip: blesta/plugins/download_manager/language/pl_pl/download_manager_files.php <==
<?php
/**
 * Download Manager Files
 *
 * @package blesta
 * @subpackage blesta.language.pl_pl
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DownloadManagerFiles.!error.file_id.exists'] = 'Aktualizowany plik nie istnieje.';
$lang['DownloadManagerFiles.!error.file_packages.format'] = 'Co najmniej jeden wybrany pakiet nie może zostać dodany, ponieważ nie istnieje.';
$lang['DownloadManagerFiles.!error.permit_packages.format'] = 'Opcja dostępności pakietu ma nieprawidłowy format.';
$lang['DownloadManagerFiles.!error.file_groups.format'] = 'Co najmniej jedna wybrana grupa klientów nie może zostać dodana, ponieważ nie istnieje.';
$lang['DownloadManagerFiles.!error.permit_client_groups.format'] = 'Opcja dostępności grupy klientów ma nieprawidłowy format.';
$lang['DownloadManagerFiles.!error.public.assignment'] = 'Plik musi być dostępny publicznie, dla grup klientów lub pakietów.';
$lang['DownloadManagerFiles.!error.public.format'] = 'Opcja dostępności publicznej ma nieprawidłowy format.';
$lang['DownloadManagerFiles.!error.file_name.format'] = 'Prześlij plik lub wprowadź prawidłową ścieżkę do pliku w katalogu uploads.';
$lang['DownloadManagerFiles.!error.name.empty'] = 'Wprowadź nazwę dla tego pliku.';
$lang['DownloadManagerFiles.!error.company_id.exists'] = 'Nieprawidłowy identyfikator firmy.';
$lang['DownloadManagerFiles.!error.category_id.exists'] = 'Wybierz odpowiednią kategorię.';
